@@ -11,7 +11,7 @@ our @EXPORT = qw(
 	VERBOSE_DOMops
 );
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use Data::Roundtrip qw/perl2dump no-unicode-escape-permanently/;
  
@@ -544,7 +544,7 @@ WWW::Mechanize::Chrome::DOMops - Operations on the DOM loaded in Chrome
 
 =head1 VERSION
 
-Version 0.08
+Version 0.09
 
 =head1 SYNOPSIS
 
@@ -989,8 +989,8 @@ one can select by C<element-class> and C<element-tag> (and ...).
 In this selection mode, the matched elements from each selector type
 (e.g. set A contains the HTML elements matched via C<element-class>
 and set B contains the HTML elements matched via C<element-tag>)
-must be combined by means of either the UNION (C<&&>)
-or INTERSECTION (C<||>) of the two sets A and B.
+must be combined by means of either the UNION (C<||>)
+or INTERSECTION (C<&&>) of the two sets A and B.
 
 Each selector can take one or more values. If you want to select
 by just one class then provide that one class as a string scalar.
